@@ -215,7 +215,7 @@ from lxml.html import clean, defs
 
 ALLOWED_TAGS = (defs.general_block_tags | defs.list_tags | defs.table_tags |
                 defs.phrase_tags | defs.font_style_tags |
-                set(('span', 'a', 'br', 'img', 'map', 'area', 'sub', 'sup'))
+                set(('span', 'a', 'br', 'img', 'map', 'area', 'sub', 'sup', 'canvas'))
                 )
 
 CLEANER = clean.Cleaner(allow_tags=ALLOWED_TAGS, remove_unknown_tags=False,
@@ -444,12 +444,14 @@ import traceback
 
 def exc_message(ex, encoding):
     try:
-        return unicode(ex)
+        excmsg = unicode(ex)
     except Exception:
         try:
-            return unicode(str(ex), encoding, 'replace')
+            excmsg = unicode(str(ex), encoding, 'replace')
         except Exception:
-            return unicode(repr(ex), encoding, 'replace')
+            excmsg = unicode(repr(ex), encoding, 'replace')
+    exctype = unicode(ex.__class__.__name__)
+    return u'%s: %s' % (exctype, excmsg)
 
 
 def rest_traceback(info, exception):
