@@ -68,7 +68,8 @@ class GenStaticDataDirMixIn(object):
             dest = osp.join(config.appdatahome, 'data')
         if osp.exists(dest):
             if (not ask_clean or
-                not ASK.confirm('Remove existing data directory %s?' % dest)):
+                not (config.verbosity and
+                     ASK.confirm('Remove existing data directory %s?' % dest))):
                 raise ExecutionError('Directory %s already exists. '
                                      'Remove it first.' % dest)
             rmtree(dest)
